@@ -1,9 +1,9 @@
-package Task::Trepan.pm;
+package Task::Trepan;
 
 use strict;
 use vars qw( $VERSION );
 BEGIN {
-    $VERSION = '1.0';
+    $VERSION = '1.1';
 }
 
 'Is that all there is to it?';
